@@ -349,7 +349,7 @@ numeric basic::ldegree(const ex & s) const
 ex basic::coeff(const ex & s, const ex & n) const
 {
 	if (is_equal(ex_to<basic>(s)))
-		return n.is_integer_one() ? _ex1 : _ex0;
+		return n.is_one() ? _ex1 : _ex0;
 	else
 		return n.is_zero() ? *this : _ex0;
 }
@@ -585,11 +585,10 @@ ex basic::subs_one_level(const exmap & m, unsigned options) const
 	exmap::const_iterator it;
 
         if (options & subs_options::no_pattern) {
-		ex thisex = *this;
-		it = m.find(thisex);
-		if (it != m.end())
-			return it->second;
-		return thisex;
+                ex thisex = *this;
+                for (const auto & pair : m)
+                        if (thisex.is_equal(pair.first))
+                                return pair.second;
 	} else {
                 for (const auto & elem : m) {
 			lst repl_lst;
