@@ -30,6 +30,7 @@
 #include "relational.h"
 #include "operators.h"
 #include "symbol.h"
+#include "constant.h"
 #include "symmetry.h"
 #include "utils.h"
 
@@ -46,7 +47,7 @@ static ex lgamma_evalf(const ex & x, PyObject* parent)
 {
 	if (is_exactly_a<numeric>(x)) {
 		try {
-			return lgamma(ex_to<numeric>(x));
+			return lgamma(ex_to<numeric>(x), parent);
 		} catch (const dunno &e) { }
 	}
 	
@@ -61,18 +62,22 @@ static ex lgamma_evalf(const ex & x, PyObject* parent)
 static ex lgamma_eval(const ex & x)
 {
 	if (x.info(info_flags::numeric)) {
-		// trap integer arguments:
-		if (x.info(info_flags::integer)) {
-			// lgamma(n) -> log((n-1)!) for postitive n
-			if (x.info(info_flags::posint))
-				return log(factorial(x + _ex_1));
-			else
-				return Infinity;
-				//throw (pole_error("lgamma_eval(): logarithmic pole",0));
-		}
-		if (!ex_to<numeric>(x).is_exact())
-			return lgamma(ex_to<numeric>(x));
-	}
+                const numeric& num = ex_to<numeric>(x);
+		
+                if (num.is_positive()) {
+                        if (num.is_integer())
+                                return log(factorial(x - _ex1));
+                        if (num.is_exact())
+                                return lgamma(x).hold();
+                        return lgamma(num);
+                }
+                else
+                        if (num.is_integer())
+                                return Infinity;
+                        //throw (pole_error("lgamma_eval(): logarithmic pole",0));
+		if (not num.is_exact())
+			return lgamma(num);
+                }
 	
 	return lgamma(x).hold();
 }
@@ -105,7 +110,7 @@ static ex lgamma_series(const ex & arg,
             or not arg_pt.info(info_flags::integer)
             or arg_pt.info(info_flags::positive))
 		throw do_taylor();  // caught by function::series()
-	// if we got here we have to care for a simple pole of tgamma(-m):
+	// if we got here we have to care for a simple pole of gamma(-m):
 	numeric m = -ex_to<numeric>(arg_pt);
 	ex recur;
 	for (numeric p = 0; p<=m; ++p)
@@ -140,69 +145,57 @@ REGISTER_FUNCTION(lgamma, eval_func(lgamma_eval).
 // true Gamma function
 //////////
 
-static ex tgamma_evalf(const ex & x, PyObject* parent)
-{
-	if (is_exactly_a<numeric>(x)) {
-		try {
-			return tgamma(ex_to<numeric>(x), parent);
-		} catch (const dunno &e) { }
-	}
-	
-	return tgamma(x).hold();
-}
-
-
-/** Evaluation of tgamma(x), the true Gamma function.  Knows about integer
+/** Evaluation of gamma(x), the true Gamma function.  Knows about integer
  *  arguments, half-integer arguments and that's it. Somebody ought to provide
  *  some good numerical evaluation some day...
  *
- *  @exception pole_error("tgamma_eval(): simple pole",0) */
-static ex tgamma_eval(const ex & x)
+ *  @exception pole_error("gamma_eval(): simple pole",0) */
+static ex gamma_eval(const ex & x)
 {
 	if (is_exactly_a<numeric>(x)) {
 		// trap integer arguments:
 		const numeric two_x = (*_num2_p)*ex_to<numeric>(x);
 		if (two_x.is_even()) {
-			// tgamma(n) -> (n-1)! for positive n
+			// gamma(n) -> (n-1)! for positive n
 			if (two_x.is_positive()) {
 				return factorial(ex_to<numeric>(x).sub(*_num1_p));
 			} else {
-				//throw (pole_error("tgamma_eval(): simple pole",1));
+				//throw (pole_error("gamma_eval(): simple pole",1));
 				return UnsignedInfinity;
 			}
 		}
 		// trap half integer arguments:
 		if (two_x.is_integer()) {
 			// trap positive x==(n+1/2)
-			// tgamma(n+1/2) -> Pi^(1/2)*(1*3*..*(2*n-1))/(2^n)
+			// gamma(n+1/2) -> Pi^(1/2)*(1*3*..*(2*n-1))/(2^n)
 			if (two_x.is_positive()) {
 				long n = ex_to<numeric>(x).sub(*_num1_2_p).to_long();
 				return (doublefactorial(n+n-1).div(_num2_p->pow_intexp(n))) * sqrt(Pi);
 			} else {
 				// trap negative x==(-n+1/2)
-				// tgamma(-n+1/2) -> Pi^(1/2)*(-2)^n/(1*3*..*(2*n-1))
+				// gamma(-n+1/2) -> Pi^(1/2)*(-2)^n/(1*3*..*(2*n-1))
 				long n = std::labs(ex_to<numeric>(x).sub(*_num1_2_p).to_long());
 				return _num_2_p->pow_intexp(n).div(doublefactorial(n+n-1))*sqrt(Pi);
 			}
 		}
 		if (!ex_to<numeric>(x).is_exact())
-			return tgamma_evalf(ex_to<numeric>(x), nullptr);
+			return gamma(ex_to<numeric>(x), nullptr);
 	}
 	
-	return tgamma(x).hold();
+	return gamma(x).hold();
 }
 
 
-static ex tgamma_deriv(const ex & x, unsigned deriv_param)
+static ex gamma_deriv(const ex & x, unsigned deriv_param)
 {
 	GINAC_ASSERT(deriv_param==0);
 	
-	// d/dx  tgamma(x) -> psi(x)*tgamma(x)
-	return psi(x)*tgamma(x);
+	// d/dx  gamma(x) -> psi(x)*gamma(x)
+	return psi(x)*gamma(x);
 }
 
 
-static ex tgamma_series(const ex & arg,
+static ex gamma_series(const ex & arg,
                         const relational & rel,
                         int order,
                         unsigned options)
@@ -211,10 +204,10 @@ static ex tgamma_series(const ex & arg,
 	// Taylor series where there is no pole falls back to psi function
 	// evaluation.
 	// On a pole at -m use the recurrence relation
-	//   tgamma(x) == tgamma(x+1) / x
+	//   gamma(x) == gamma(x+1) / x
 	// from which follows
-	//   series(tgamma(x),x==-m,order) ==
-	//   series(tgamma(x+m+1)/(x*(x+1)*...*(x+m)),x==-m,order);
+	//   series(gamma(x),x==-m,order) ==
+	//   series(gamma(x+m+1)/(x*(x+1)*...*(x+m)),x==-m,order);
 	const ex arg_pt = arg.subs(rel, subs_options::no_pattern);
 	if (not is_exactly_a<numeric>(arg_pt)
             or not arg_pt.info(info_flags::integer)
@@ -225,26 +218,25 @@ static ex tgamma_series(const ex & arg,
 	ex ser_denom = _ex1;
 	for (numeric p; p<=m; ++p)
 		ser_denom *= arg+p;
-	return (tgamma(arg+m+_ex1)/ser_denom).series(rel, order, options);
+	return (gamma(arg+m+_ex1)/ser_denom).series(rel, order, options);
 }
 
-static void tgamma_print_dflt(const ex & arg, const print_context & c)
+static void gamma_print_dflt(const ex & arg, const print_context & c)
 {  c.s << "gamma("; arg.print(c); c.s << ")"; }
 
-static ex tgamma_conjugate(const ex & x)
+static ex gamma_conjugate(const ex & x)
 {
-	// conjugate(tgamma(x))==tgamma(conjugate(x))
-	return tgamma(x.conjugate());
+	// conjugate(gamma(x))==gamma(conjugate(x))
+	return gamma(x.conjugate());
 }
 
 
-REGISTER_FUNCTION(tgamma, eval_func(tgamma_eval).
-                          evalf_func(tgamma_evalf).
-                          derivative_func(tgamma_deriv).
-                          series_func(tgamma_series).
-                          conjugate_func(tgamma_conjugate).
+REGISTER_FUNCTION(gamma, eval_func(gamma_eval).
+                          derivative_func(gamma_deriv).
+                          series_func(gamma_series).
+                          conjugate_func(gamma_conjugate).
                           latex_name("\\Gamma").
-		          print_func<print_dflt>(tgamma_print_dflt));
+		          print_func<print_dflt>(gamma_print_dflt));
 
 
 //////////
@@ -256,9 +248,7 @@ static ex beta_evalf(const ex & x, const ex & y, PyObject* parent)
 	if (is_exactly_a<numeric>(x) && is_exactly_a<numeric>(y)) {
 		const numeric &nx = ex_to<numeric>(x);
 		const numeric &ny = ex_to<numeric>(y);
-                if (parent == nullptr)
-                        parent = CC_get();
-                return (nx+ny).rgamma(parent) * nx.tgamma(parent) * ny.tgamma(parent);
+                return (nx+ny).rgamma(parent) * nx.gamma(parent) * ny.gamma(parent);
 	}
 	
 	return beta(x,y).hold();
@@ -267,12 +257,14 @@ static ex beta_evalf(const ex & x, const ex & y, PyObject* parent)
 
 static ex beta_eval(const ex & x, const ex & y)
 {
-	if (x.is_equal(_ex1))
-		return 1/y;
-	if (y.is_equal(_ex1))
-		return 1/x;
+        if (x.is_zero() or y.is_zero())
+                return NaN;
+	if (x.is_one())
+		return power(y, _ex_1);
+	if (y.is_one())
+		return power(x, _ex_1);
 	if (is_exactly_a<numeric>(x) and is_exactly_a<numeric>(y)) {
-		// treat all problematic x and y that may not be passed into tgamma,
+		// treat all problematic x and y that may not be passed into gamma,
 		// because they would throw there although beta(x,y) is well-defined
 		// using the formula beta(x,y) == (-1)^y * beta(1-x-y, y)
 		const numeric &nx = ex_to<numeric>(x);
@@ -291,7 +283,7 @@ static ex beta_eval(const ex & x, const ex & y)
 				else
 					throw (pole_error("beta_eval(): simple pole",1));
 			}
-			return tgamma(x)*tgamma(y)/tgamma(x+y);
+			return gamma(x)*gamma(y)/gamma(x+y);
 		}
 		// no problem in numerator, but denominator has pole:
 		if ((nx+ny).is_real() &&
@@ -328,9 +320,9 @@ static ex beta_series(const ex & arg1,
                       unsigned options)
 {
 	// method:
-	// Taylor series where there is no pole of one of the tgamma functions
+	// Taylor series where there is no pole of one of the gamma functions
 	// falls back to beta function evaluation.  Otherwise, fall back to
-	// tgamma series directly.
+	// gamma series directly.
 	const ex arg1_pt = arg1.subs(rel, subs_options::no_pattern);
 	const ex arg2_pt = arg2.subs(rel, subs_options::no_pattern);
 	GINAC_ASSERT(is_a<symbol>(rel.lhs()));
@@ -341,19 +333,19 @@ static ex beta_series(const ex & arg1,
 		throw do_taylor();  // caught by function::series()
 	// trap the case where arg1 is on a pole:
 	if (arg1.info(info_flags::integer) && !arg1.info(info_flags::positive))
-		arg1_ser = tgamma(arg1+s);
+		arg1_ser = gamma(arg1+s);
 	else
-		arg1_ser = tgamma(arg1);
+		arg1_ser = gamma(arg1);
 	// trap the case where arg2 is on a pole:
 	if (arg2.info(info_flags::integer) && !arg2.info(info_flags::positive))
-		arg2_ser = tgamma(arg2+s);
+		arg2_ser = gamma(arg2+s);
 	else
-		arg2_ser = tgamma(arg2);
+		arg2_ser = gamma(arg2);
 	// trap the case where arg1+arg2 is on a pole:
 	if ((arg1+arg2).info(info_flags::integer) && !(arg1+arg2).info(info_flags::positive))
-		arg1arg2_ser = tgamma(arg2+arg1+s);
+		arg1arg2_ser = gamma(arg2+arg1+s);
 	else
-		arg1arg2_ser = tgamma(arg2+arg1);
+		arg1arg2_ser = gamma(arg2+arg1);
 	// compose the result (expanding all the terms):
 	return (arg1_ser*arg2_ser/arg1arg2_ser).series(rel, order, options).expand();
 }
@@ -371,6 +363,7 @@ REGISTER_FUNCTION(beta, eval_func(beta_eval).
 // Psi-function (aka digamma-function)
 //////////
 
+// Needed because there is no RR member function
 static ex psi1_evalf(const ex & x, PyObject* parent)
 {
 	if (is_exactly_a<numeric>(x)) {
@@ -495,9 +488,9 @@ static ex psi2_eval(const ex & n, const ex & x)
 	// psi(0,x) -> psi(x)
 	if (n.is_zero())
 		return psi(x);
-	// psi(-1,x) -> log(tgamma(x))
+	// psi(-1,x) -> log(gamma(x))
 	if (n.is_equal(_ex_1))
-		return log(tgamma(x));
+		return log(gamma(x));
 	if (is_exactly_a<numeric>(n)
             and n.info(info_flags::posint)
 	    and is_exactly_a<numeric>(x)) {
